#include <stdio.h>
#include <stdlib.h>
#include <string.h>

//***********************************************************************

class Point {
	double dX,dY;

	public:

	Point(double dX,double dY);
	Point(FILE *fin);
	double X();
	double Y();
	void print();
};

Point::Point(double dX,double dY) 
{
	this->dX = dX;
	this->dY = dY;
}

Point::Point(FILE *fin)
{
	int iX,iY;
	fscanf(fin,"%d%d",&iX,&iY);
	dX = iX;
	dY = iY;
}

void Point::print()
{
	printf("%.2f %.2f\n",dX,dY);
}

double Point::X()
{
	return dX;
}

double Point::Y()
{
	return dY;
}

//***********************************************************************

class Segment {
	Point *p1,*p2;

	public:

	Segment(Point *p1,Point *p2);
	static bool intersect(Segment *s1,Segment *s2);
};

Segment::Segment(Point *p1,Point *p2)
{
	this->p1 = p1;
	this->p2 = p2;
}

bool Segment::intersect(Segment *s1,Segment *s2) 
{
	bool b1 = false;

	{
		double iVec1_X = s1->p2->X() - s1->p1->X();
		double iVec1_Y = s1->p2->Y() - s1->p1->Y();

		double iVec2_X = s2->p1->X() - s1->p1->X();
		double iVec2_Y = s2->p1->Y() - s1->p1->Y();

		double iVec3_X = s2->p2->X() - s1->p1->X();
		double iVec3_Y = s2->p2->Y() - s1->p1->Y();

		double iP1 = iVec1_X*iVec2_Y - iVec1_Y*iVec2_X;
		double iP2 = iVec1_X*iVec3_Y - iVec1_Y*iVec3_X;

		if (iP1 == 0)
			b1 = true;
		if (iP2 == 0)
			b1 = true;
		if (iP1 > 0 && iP2 < 0)
			b1 = true;
		if (iP1 < 0 && iP2 > 0)
			b1 = true;
	}
	
	bool b2 = false;

	{
		double iVec1_X = s2->p2->X() - s2->p1->X();
		double iVec1_Y = s2->p2->Y() - s2->p1->Y();

		double iVec2_X = s1->p1->X() - s2->p1->X();
		double iVec2_Y = s1->p1->Y() - s2->p1->Y();

		double iVec3_X = s1->p2->X() - s2->p1->X();
		double iVec3_Y = s1->p2->Y() - s2->p1->Y();

		double iP1 = iVec1_X*iVec2_Y - iVec1_Y*iVec2_X;
		double iP2 = iVec1_X*iVec3_Y - iVec1_Y*iVec3_X;

		if (iP1 == 0)
			b2 = true;
		if (iP2 == 0)
			b2 = true;
		if (iP1 > 0 && iP2 < 0)
			b2 = true;
		if (iP1 < 0 && iP2 > 0)
			b2 = true;
	}

	return ( b1 && b2 );
}

//***********************************************************************

class Rect {
	Point p1,p2;
	Point p3,p4;

	public:

	Rect(FILE *fin);
	Rect(Point p1,Point p2);
	Point *getPoint(int iP);
	Segment getSegment(int iSeg);
};

Rect::Rect(FILE *fin):  p1(fin),
			p2(fin),
			p3(p1.X(),p2.Y()),
			p4(p2.X(),p1.Y())
{
	
}


Rect::Rect(Point p1,Point p2): p1(p1),
			       p2(p2),
			       p3(p1.X(),p2.Y()),
			       p4(p1.Y(),p2.X())
{
	
}

Point* Rect::getPoint(int iP)
{
	switch (iP) {
		case 0: return &p1;
		case 1: return &p2;
		case 2: return &p3;
		case 3: return &p4;
	}
	return NULL;
}

Segment Rect::getSegment(int iSeg)
{
	switch (iSeg) {
		case 0: return Segment(&p1,&p3);
		case 1: return Segment(&p1,&p4);
		case 2: return Segment(&p2,&p3);
		case 3: return Segment(&p2,&p4);
	}	
}

//*********************************************************************** 

class Vertex{
	int iMaxEdgeCount;
	int iEdgeCount;
	int *edge;

	public:

	Vertex(int iMaxEdgeCount);
	~Vertex();
	void addEdge(int iV);	
	int getEdgeCount();
	int getEdge(int iE);
};	

int Vertex::getEdgeCount()
{
	return iEdgeCount;
}

int Vertex::getEdge(int iE)
{
	return edge[iE];
}

Vertex::Vertex(int iMaxEdgeCount)
{
	this->iMaxEdgeCount = iMaxEdgeCount;
	iEdgeCount = 0;
	edge = new int[iMaxEdgeCount];
}

Vertex::~Vertex()	
{
	delete []edge;
}

void Vertex::addEdge(int iV)
{
	edge[iEdgeCount++] = iV;
}

//*********************************************************************** 

class Graph {
	int iVC;
	Vertex **v;

	public:

	Graph(int iVC);
	~Graph();
	void addEdge(int iV1,int iV2);
	int getVC();
	Vertex *getVertex(int iV);
};

int Graph::getVC() 
{
	return iVC;
}

Vertex* Graph::getVertex(int iV)
{
	return v[iV];
}

Graph::Graph(int iVC)
{
	this->iVC = iVC;
	v = new Vertex*[iVC];
	for (int i=0;i<iVC;i++)
		v[i] = new Vertex(iVC);

}

Graph::~Graph() 
{
	for (int i=0;i<iVC;i++)
		delete v[i];
	delete []v;
}

void Graph::addEdge(int iV1,int iV2)
{
	v[iV1]->addEdge(iV2);
	v[iV2]->addEdge(iV1);
}

//*********************************************************************** 

void save(int *vstack,int iPathL);

class PathFinder {
	Graph *g;
	int iStart;
	int iEnd;
	int *vstack;
	bool *bvis;
	int iPathL;

	bool do_find(int iCurV);

	public:	

	PathFinder(Graph *g,int iStart,int iEnd);
	~PathFinder();
	void run();
};

bool PathFinder::do_find(int iCurV)
{
	if (iCurV == iEnd) {
		iPathL++;
		vstack[iPathL-1] = iCurV;
		return true;
	}
	if (bvis[iCurV] == true)
		return false;

	iPathL++;
	vstack[iPathL-1] = iCurV;
	bvis[iCurV] = true;

	Vertex *v = g->getVertex(iCurV);
	int iEC = v->getEdgeCount();
	for (int iE=0;iE<iEC;iE++) {
		int iV = v->getEdge(iE);
		if (do_find(iV))
			return true;
	}

	iPathL--;
	return false;
}

PathFinder::PathFinder(Graph *g,int iStart,int iEnd)
{
	this->g = g;
	this->iStart = iStart;
	this->iEnd = iEnd;
	vstack = new int[g->getVC()];
	bvis = new bool[g->getVC()];
	memset(bvis,0,sizeof(bool)*(g->getVC()));
	iPathL = 0;
}

PathFinder::~PathFinder()
{
	delete []vstack;
	delete []bvis;
}

void PathFinder::run()
{
	do_find(iStart);
	save(vstack,iPathL);
}

//*********************************************************************** 

Point *start;
Point *end;
Rect **rect;
Point **waypoint;
int iWaypointC;
int iRectC;

void load() 
{
	//FILE *fin = fopen("path.inp","r");
	FILE *fin = stdin;

	int iX,iY,iRectC,i;

	fscanf(fin,"%d%d%d",&iX,&iY,&iRectC);
	iRectC++;
	::iRectC = iRectC;	
	start = new Point(0,0);
	end = new Point(iX,iY);

	rect = new Rect*[iRectC];
	for (i=0;i<iRectC-1;i++)
		rect[i] = new Rect(fin);
	rect[iRectC-1] = new Rect(Point(-0.1,-0.1),
		                  Point(end->X()+0.1,end->Y()+0.1));

	iWaypointC = iRectC*4 + 2 - 4;
	waypoint = new Point*[iWaypointC];
	memset(waypoint,0,sizeof(Point*)*(iWaypointC));
	waypoint[0] = start;
	waypoint[iWaypointC - 1] = end;	
	for (i=0;i<iRectC-1;i++) {
		Point *p;

		p = new Point(rect[i]->getPoint(0)->X() - 0.5,
			      rect[i]->getPoint(0)->Y() - 0.5); 
		waypoint[i*4 + 1 + 0] = p;

		p = new Point(rect[i]->getPoint(1)->X() + 0.5,
			      rect[i]->getPoint(1)->X() + 0.5); 
		waypoint[i*4 + 1 + 1] = p;

		p = new Point(rect[i]->getPoint(0)->X() - 0.5,
			      rect[i]->getPoint(1)->Y() + 0.5); 
		waypoint[i*4 + 1 + 2] = p;

		p = new Point(rect[i]->getPoint(1)->X() + 0.5,
			      rect[i]->getPoint(0)->Y() - 0.5); 
		waypoint[i*4 + 1 + 3] = p;
	}

	//fclose(fin);
}

bool goodEdge(Point *p1,Point *p2) 
{
	Segment s(p1,p2);

	for (int iR=0;iR<iRectC;iR++) {
		for (int iSeg=0;iSeg<4;iSeg++) {
			Segment s1 = rect[iR]->getSegment(iSeg);

			if ( Segment::intersect(&s,&s1) )
				return false;	
		}
	}
	return true;
}


void buildGraph(Graph *g)
{

	for (int iV1=0;iV1<iWaypointC;iV1++)
		for (int iV2=0;iV2<iWaypointC;iV2++) {
			if (iV1 == iV2)
				continue;
			//printf("%d %d\n",iV1,iV2);
			if (goodEdge(waypoint[iV1],waypoint[iV2]))
				g->addEdge(iV1,iV2);
		}
}

void findPath(Graph *g)
{
	PathFinder *pf = new PathFinder(g,0,g->getVC() - 1);
	pf->run();
	delete pf;	
}

void solve() 
{
	Graph *g = new Graph(iWaypointC);

	buildGraph(g);
	findPath(g);

	delete g;
}

void save(int *vstack,int iPathL)
{
	if (iPathL == 0) {
		printf("-1\n");
		return;
	}
	for (int i=1;i<iPathL;i++)
		waypoint[vstack[i]]->print();
}

void freeDS() 
{
	delete start;
	delete end;

	int i;

	for (i=0;i<iRectC;i++)
		delete rect[i];
	delete []rect;

	for (i=1;i<iWaypointC-1;i++)
		delete waypoint[i];
	delete []waypoint;
}

void segment_test()
{
	Point p1(0,0);
	Point p2(10,10);

	Point p3(9,11);
	Point p4(11,10);

	Segment s1(&p1,&p2);
	Segment s2(&p3,&p4);

	if (Segment::intersect(&s1,&s2))
		printf("True\n");
	else
		printf("False\n");

	exit(0);
}

int main() 
{
	//segment_test();
	load();	
	solve();
	freeDS();

	return 0;
}